# Auto Iserv v.0.1.8

This is a library for python, that can be used to create tools to automate Iserv **without** an API key
The only thing that is needed is a Iserv account with a username and password.
It is recommended to use a credential file, but you can hardcode your password and username.
This can be done by typing : `gen-iserv-credential`

There are pre written Modules, but you can also create your own module automation.


# Contributing
You can make pull requests and I will be happy to look at them.
If you don't know what to contribute you could add more pre written modules.

# Example
If you want an example you might want to look at [this](https://github.com/RedstoneMedia/IServ-exercise-discord-bot)

## Installation
Install this package using pip :
`pip install auto-iserv`
